export interface Role {
  roleId: number;
  roleCode: "ORG_ADMIN" | "SUPER_ADMIN" | "ROOT_ORG_ADMIN" | "COURSE_ADMIN";
  roleName: string;
}

export type Course_Type = "PUBLIC" | "MAJOR";

export type Privilege_Type = "COURSE" | "ORG";

export interface Question {
  id: number;
  createTime: string;
  updateTime: string;
  projectId: number;
  courseId: number;
  paperId: number;
  questionName: string;
  mainNumber: number;
  subNumber: number;
  subIndex: null;
  objective: boolean;
  totalScore: number;
  maxScore: number;
  minScore: number;
  avgScore: number;
  stdev: number;
  coefficient: number;
  difficulty: number;
  discrimination: number;
  zeroCount: number;
  fullCount: number;
  effectiveCount: number;
  options: null;
  optionLevel: null;
  answer: null;
  difficulityLevel: number[];
  difficulityGroupLevel: number[];
}

// Generated by https://quicktype.io

export interface QuestionGroup {
  avgScore: number;
  coefficient: number;
  courseId: number;
  createTime: string;
  difficulityLevel: {
    high: {
      questionCount: number;
      fullScore: number;
      percent: number;
    };
    middle: {
      questionCount: number;
      fullScore: number;
      percent: number;
    };
    low: {
      questionCount: number;
      fullScore: number;
      percent: number;
    };
  };
  difficulty: number;
  discrimination: number;
  discriminationLevel: {
    excellent: {
      questionCount: number;
      fullScore: number;
    };
    good: {
      questionCount: number;
      fullScore: number;
    };
    general: {
      questionCount: number;
      fullScore: number;
    };
    bad: {
      questionCount: number;
      fullScore: number;
    };
  };
  fullCount: number;
  groupName: string;
  id: number;
  maxScore: number;
  minScore: number;
  objective: boolean;
  paperId: number;
  projectId: number;
  questionCount: number;
  realityCount: number;
  stdev: number;
  totalScore: number;
  type:
    | "TYPE1"
    | "TYPE2"
    | "TYPE3"
    | "CONTENT1"
    | "CONTENT2"
    | "CONTENT3"
    | "ABILITY1"
    | "ABILITY2"
    | "ABILITY3";
  updateTime: string;
  zeroCount: number;
}

// 科目成绩（总分）频率分布-科目成绩占初试总分权重
export interface SasCourse {
  courseCode: string;
  courseId: number;
  courseName: string;
  difficulty: number;
  id: number;
  projectId: number;
  rangeConfig: RangeConfig[];
  scoreRange: number[];
  totalCount: number;
  totalRangeConfig: string;
  totalScore: number;
  totalScoreRange: string;
  totalScoreRangeTitle: string;

  segements: number[][]; // 前端自用
  rangeSegements: (string | number | boolean)[][]; // 前端自用
  scoreRangeAcc: number[]; // 前端自用
  scoreRangeTotal: number; // 前端自用
}

export interface RangeConfig {
  type: keyof RANGE_POINT_TYPE;
  baseScore: number;
  adjustScore: number;
}

export interface RANGE_POINT_TYPE {
  ZERO: "零分";
  CUSTOM: "自定义";
  NATIONAL_SCORE: "国家单科线";
  RETEST_SCORE: "复试单科线";
  NATIONAL_TOTAL_SCORE: "国家总分线";
  RETEST_TOTAL_SCORE: "复试总分线";
  TOTAL_SCORE_LINE: "国家满分线";
}

// 整体分析-试卷特征量数
export interface SASPaper {
  allRange: number;
  avgScore: number;
  coefficient: number;
  courseCode: string;
  courseId: number;
  courseName: string;
  difficulty: number;
  id: number;
  maxScore: number;
  minScore: number;
  paperId: number;
  paperName: string;
  paperType: string;
  projectId: number;
  reliability1: number;
  reliability2: number;
  stdev: number;
  totalScore: number;
}

export interface Pagination {
  pageNo: number;
  pageSize: number;
  totalElements: number;
}

export interface SASPaperResponse extends Pagination {
  content: SASPaper[];
}
